# Erin_etal_2019_Diplo_Graphs
# Date: March 2019
# Code description: code to replicate data visualisation of D. pseudospathaceum experimental infection data from Erin et al. 2019 (J. Anim. Ecol)
# Code authors: Code developed by Noemie I. Erin, and Daniel P. Benesh

# Clear workspace
rm(list =ls())
dev.off()

# libraries
library(reshape2) #dcast
library(Rmisc)    #summarySE
library(ggplot2)  #ggplot
library(scales)   #percent_format
library(lme4)     #lmer












######################################################################################################################
################################################      Data input      ################################################
######################################################################################################################

setwd("C:/")

# import dataset:
input_file_dpl <- "/Erin_etal_2019_Diplo.txt"

data_dpl <- read.delim(input_file_dpl)












#>>>>> To load data, run script until 'Data Vizualisation' >>>>>

######################################################################################################################
###################################      Data subsets & Parameter calculations      ##################################
######################################################################################################################

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Data rescaling

# reunited fish family
levels(data_dpl$fish.family)[levels(data_dpl$fish.family)=="SKO-Hyb-L003MxR003F/2"] <- "SKO-Hyb-L003MxR003F"

# put weight into kg - allows model fitting
data_dpl <- mutate(data_dpl, somatic.weight.kg = somatic.weight/1000)

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Subsets

# Removing GPS fish
data_dpl2 <- data_dpl[!data_dpl$family.type %in% c("GPS-Lake"), ]

# all infected fish
data_dpl_inf <- data_dpl2[data_dpl2$inf.status_cat %in% c("infected"), ]

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Infection rate (per fish family)

## Count the occurence of "infected" vs. "unifected" for each fish family
data_IR    <- as.data.frame(dcast(fish.family + family.type ~ inf.status_cat,       # contengency table
                                data = data_dpl,
                                fun.aggregate = length))

## Calculate proportion of infected fish for each fish family
data_IR$IR <- (data_IR$infected/(data_IR$infected + data_IR$uninfected))#*100     # infection rate calculation

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Mean infection rate (per fish family type)

SEall_IR    <- summarySE(data_IR, measurevar = "IR", groupvars = "family.type", na.rm = T)
SEall_inf   <- summarySE(data_IR, measurevar = "infected", groupvars = "family.type", na.rm = T)
SEall_uninf <- summarySE(data_IR, measurevar = "uninfected", groupvars = "family.type", na.rm = T)











#>>>>> Data Vizualisation (excluding GPS fish) >>>>>

######################################################################################################################
############################################      Data Vizualisation      ############################################
######################################################################################################################

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Infection rate

SEall_IR    <- summarySE(data_IR, measurevar = "IR", groupvars = "family.type", na.rm = T)

# Removing GPS fish
SEall_IR    <- SEall_IR[!SEall_IR$family.type %in% c("GPS-Lake"), ]
data_IR     <- data_IR[!data_IR$family.type %in% c("GPS-Lake"), ]


### Infection rate plot
pInf <- ggplot(SEall_IR, aes(x = factor(family.type), 
                             y = IR, 
                             colour = factor(family.type), 
                             fill = factor(family.type)))

#set our position argument as an object
dodge.posn.basic <- position_dodge(width = 0.4)
dodge.posn       <- position_jitterdodge(jitter.width = 0.8, dodge.width = 0.4)

pInf +
  geom_bar(stat = "identity",
           alpha = 0.5) +
  geom_pointrange(data = SEall_IR,
                  size = 2,
                  #width = 0.1,
                  aes(ymin = IR - ci,
                      ymax = IR + ci, 
                      colour = factor(family.type), 
                      fill = factor(family.type))) +
  scale_x_discrete(name = "",
                   limits = c("SKO-River", "SKO-Hybrid(LMxRF)", "SKO-Hybrid(RMxLF)", "SKO-Lake"),
                   breaks = c("SKO-River", "SKO-Hybrid(LMxRF)", "SKO-Hybrid(RMxLF)", "SKO-Lake"),
                   labels = c("SKO-River" = "RAxRA", "SKO-Hybrid(LMxRF)" = "RAxL", "SKO-Hybrid(RMxLF)" = "LxRA", "SKO-Lake" = "LxL")) +
  scale_y_continuous(name = "Infection rate\n",
                     labels = percent_format()) +
  scale_color_manual(name = "",
                     aes(colour = factor(family.type), 
                         fill = factor(family.type)),
                     labels = c("SKO-River", "SKO-Hybrid(LMxRF)", "SKO-Hybrid(RMxLF)", "SKO-Lake"),
                     values = c("SKO-River" = "#ff8d1e", "SKO-Hybrid(LMxRF)"  = "#ff8d1e", "SKO-Hybrid(RMxLF)" = "#1e90ff", "SKO-Lake"  = "#1e90ff")) +
  scale_fill_manual(name = "",
                    labels = c("SKO-River", "SKO-Hybrid(LMxRF)", "SKO-Hybrid(RMxLF)", "SKO-Lake"),
                    values = c("SKO-River" = "#ff8d1e", "SKO-Hybrid(LMxRF)"  = "#ff8d1e", "SKO-Hybrid(RMxLF)" = "#1e90ff", "SKO-Lake"  = "#1e90ff")) +
  theme(panel.background = element_blank(),
        title = element_text(colour = "black", size = 18),
        axis.line.x = element_line(colour = "black", size = 1),
        axis.line.y = element_line(colour = "black", size = 1),
        legend.position = "none",
        axis.title.x = element_text(colour = "black", size = 30, vjust = -0.4),
        axis.text.x = element_text(colour = "black", size = 30),
        axis.title.y = element_text(colour = "black", size = 30, vjust = 1),
        axis.text.y = element_text(colour = "black", size = 30),
        axis.ticks = element_line(colour = "black", size = 1),
        plot.margin = unit(c(1, 1, 1, 1),"cm"))

ggsave("pInf.pdf", width = 9, height = 8, unit = "in", dpi = 600)


#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Diplo abundance


SEalltDpl <- summarySE(data_dpl_inf, measurevar = "diplo_total", groupvars = "pop.type", na.rm = T)

### Diplo_Total plot
ptDpl <- ggplot(data_dpl_inf, aes(x = pop.type, 
                                  y = diplo_total, 
                                  colour = pop.type, 
                                  fill = pop.type, 
                                  group = pop.type))

#set our position argument as an object
dodge.posn.basic <-position_dodge(width = 0.4)
dodge.posn       <- position_jitterdodge(jitter.width = 0.8, dodge.width = 0.4)


ptDpl +
  geom_point(shape = 16, 
             size = 5,
             alpha = 0.2,
             position = dodge.posn) +
  stat_summary(fun.data = mean_cl_boot, # 95% CI
               fun.args = (conf.int = 0.95),
               size = 1,
               width = 0.2,
               geom = "errorbar",
               color = "black",
               position = dodge.posn.basic) +
  stat_summary(fun.y = mean,
               geom = "point",
               shape = 19,
               size = 10,
               position = dodge.posn.basic) +
  scale_x_discrete(name = "",
                   limits = c("SKO-River", "SKO-Hyb", "SKO-Lake"),
                   breaks = c("SKO-River", "SKO-Hyb", "SKO-Lake"),
                   labels = c("SKO-River" = "River", "SKO-Hyb" = "Hybrids", "SKO-Lake" = "Lake")) +
  scale_y_continuous(name = "Metacercariae abundance\n",
                     limit = c(0,50),
                     expand = c(0,0)) +
  scale_colour_manual(name = "",
                      labels = c("SKO-River", "SKO-Hyb", "SKO-Lake"),
                      values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff")) +
  scale_fill_manual(name = "",
                    labels = c("SKO-River", "SKO-Hyb", "SKO-Lake"),
                    values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff")) +
  theme(panel.background = element_blank(),
        title = element_text(colour = "black", size = 18),
        axis.line.x = element_line(colour = "black", size = 1),
        axis.line.y = element_line(colour = "black", size = 1),
        legend.position = "none",
        axis.title.x = element_text(colour = "black", size = 30, vjust = -0.4),
        axis.text.x = element_text(colour = "black", size = 30),
        axis.title.y = element_text(colour = "black", size = 33, vjust = 1),
        axis.text.y = element_text(colour = "black", size = 30),
        axis.ticks = element_line(colour = "black", size = 1),
        plot.margin = unit(c(1, 1, 1, 1),"cm"))

## Export
ggsave("ptDpl.pdf", width = 9, height = 8, unit = "in", dpi = 600)


#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Fish parameters


### Fish condition
dat_cond_red <- na.omit(data_dpl2[, c("SL", "somatic.weight.kg", "sex", "family.type", "pop.type", "fish.family.M", "fish.family.F")])  # removing NAs
modx <- lmer(log10(somatic.weight.kg) ~ log10(SL) + sex + (1|fish.family.M) + (1|fish.family.F),
             data = dplyr::filter(dat_cond_red, pop.type != "GPS-Lake"))
dat_cond_red$mod_resid <- resid(modx)

pRFW <- ggplot(dat_cond_red,
               aes(x = pop.type,
                   y = mod_resid,
                   shape = pop.type,
                   colour = pop.type,
                   fill = pop.type,
                   group = pop.type))
ttl.y <- "Fish condition\n"
lim <- c(-0.13,0.13)


### Residual liver weight
dat_cond_red <- na.omit(data_dpl2[, c("liver", "somatic.weight.kg", "sex", "family.type", "pop.type", "fish.family.M", "fish.family.F")])  # removing NAs
modx <- lmer(log10(liver) ~ log10(somatic.weight.kg) + sex + (1|fish.family.M) + (1|fish.family.F),
             data = dplyr::filter(dat_cond_red, pop.type != "GPS-Lake"))
dat_cond_red$mod_resid <- resid(modx)

pRLW <- ggplot(dat_cond_red,
               aes(x = pop.type,
                   y = mod_resid,
                   shape = pop.type,
                   colour = pop.type,
                   fill = pop.type,
                   group = pop.type))
ttl.y <- "Residual liver weight\n"
lim <- c(-0.3,0.3)


### Residual spleen weight
dat_cond_red <- na.omit(data_dpl2[, c("spleen", "somatic.weight.kg", "sex", "family.type", "pop.type", "fish.family.M", "fish.family.F")])  # removing NAs
modx <- lmer(log10(spleen) ~ log10(somatic.weight.kg) + sex + (1|fish.family.M) + (1|fish.family.F),
             data = dplyr::filter(dat_cond_red, pop.type != "GPS-Lake"))
dat_cond_red$mod_resid <- resid(modx)

pRSW <- ggplot(dat_cond_red,
               aes(x = pop.type,
                   y = mod_resid,
                   shape = pop.type,
                   colour = pop.type,
                   fill = pop.type,
                   group = pop.type))
ttl.y <- "Residual spleen weight\n"
lim <- c(-1,1)


### Residual HK weight
dat_cond_red <- na.omit(data_dpl2[, c("HK", "somatic.weight.kg", "sex", "family.type", "pop.type", "fish.family.M", "fish.family.F")])  # removing NAs
modx <- lmer(log10(HK) ~ log10(somatic.weight.kg) + sex + (1|fish.family.M) + (1|fish.family.F),
             data = dplyr::filter(dat_cond_red, pop.type != "GPS-Lake"))
dat_cond_red$mod_resid <- resid(modx)

pRHKW <- ggplot(dat_cond_red,
                aes(x = pop.type,
                    y = mod_resid,
                    shape = pop.type,
                    colour = pop.type,
                    fill = pop.type,
                    group = pop.type))
ttl.y <- "Residual head kidney weight\n"
lim <- c(-1.2,1.2)


#set our position argument as an object
dodge.posn.basic <- position_dodge(width = 0.4)
dodge.posn       <- position_jitterdodge(jitter.width = 0.8, dodge.width = 0.4)


pRFW +
  #pRLW +
  #pRSW +
  #pRHKW +
  geom_point(shape = 16, 
             size = 5,
             alpha = 0.1,
             position = dodge.posn) +
  stat_summary(fun.data = mean_cl_boot, # 95% CI
               fun.args = (conf.int = 0.95),
               size = 1,
               width = 0.2,
               geom = "errorbar",
               color = "black",
               position = dodge.posn.basic) +
  stat_summary(fun.y = mean,
               geom = "point",
               shape = 19,
               size = 10,
               position = dodge.posn.basic) +
  scale_x_discrete(name = "",
                   limits = c("SKO-River", "SKO-Hyb", "SKO-Lake"),
                   breaks = c("SKO-River", "SKO-Hyb", "SKO-Lake"),
                   labels = c("SKO-River" = "River", "SKO-Hyb" = "Hybrids", "SKO-Lake" = "Lake")) +
  scale_y_continuous(ttl.y,
                     limits = lim,
                     breaks = pretty_breaks(n = 4),
                     expand = c(0,0)) +
  scale_colour_manual(name = "",
                      labels = c("SKO-River", "SKO-Hyb", "SKO-Lake"),
                      values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff")) +
  scale_fill_manual(name = "", #name = "Fish population",
                    labels = c("SKO-River", "SKO-Hyb", "SKO-Lake"),
                    values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff")) +
    theme(panel.background = element_blank(),
        title = element_text(colour = "black", size = 18),
        axis.line.x = element_line(colour = "black", size = 1),
        axis.line.y = element_line(colour = "black", size = 1),
        legend.position = "none",
        axis.title.x = element_text(colour = "black", size = 30, vjust = -0.4),
        axis.text.x = element_text(colour = "black", size = 30),
        axis.title.y = element_text(colour = "black", size = 33, vjust = 1),
        axis.text.y = element_text(colour = "black", size = 33),
        axis.ticks = element_line(colour = "black", size = 1),
        plot.margin = unit(c(1, 1, 1, 1),"cm"))

## Export
ggsave("CFplot.pdf", width = 9, height = 8, unit = "in", dpi = 600)












#>>>>> Data Vizualisation (including GPS fish) >>>>>

######################################################################################################################
############################################      Data Vizualisation      ############################################
######################################################################################################################

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Infection rate

## Count the occurence of "infected" vs. "unifected" for each fish family
data_IR    <- as.data.frame(dcast(fish.family + pop.type ~ inf.status_cat,       # contengency table
                                  data = data_dpl,
                                  fun.aggregate = length))

## Calculate proportion of infected fish for each fish family
data_IR$IR <- (data_IR$infected/(data_IR$infected + data_IR$uninfected))#*100     # infection rate calculation


SEall_IR    <- summarySE(data_IR, measurevar = "IR", groupvars = "pop.type", na.rm = T)

### Infection rate plot
pInf <- ggplot(SEall_IR, aes(x = pop.type, 
                             y = IR, 
                             colour = pop.type, 
                             fill = pop.type))

#set our position argument as an object
dodge.posn.basic <- position_dodge(width = 0.4)
dodge.posn       <- position_jitterdodge(jitter.width = 0.8, dodge.width = 0.4)

pInf +
  geom_bar(stat = "identity",
           alpha = 0.5) +
  geom_pointrange(data = SEall_IR,
                  size = 2,
                  #width = 0.1,
                  aes(ymin = IR - ci,
                      ymax = IR + ci, 
                      colour = pop.type, 
                      fill = pop.type)) +
  scale_x_discrete(name = "",
                   limits = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                   breaks = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                   labels = c("SKO-River" = "River", "SKO-Hyb" = "Hybrids", "SKO-Lake" = "Lake", "GPS-Lake" = "GPS")) +
  scale_y_continuous(name = "Infection rate\n",
                     labels = percent_format()) +
  scale_colour_manual(name = "",
                      aes(colour = pop.type, 
                          fill = pop.type),
                      labels = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                      values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff", "GPS-Lake" = "dodgerblue3")) +
  scale_fill_manual(name = "",
                    labels = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                    values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff", "GPS-Lake" = "dodgerblue3")) +
  theme(panel.background = element_blank(),
        title = element_text(colour = "black", size = 18),
        axis.line.x = element_line(colour = "black", size = 1),
        axis.line.y = element_line(colour = "black", size = 1),
        legend.position = "none",
        axis.title.x = element_text(colour = "black", size = 30, vjust = -0.4),
        axis.text.x = element_text(colour = "black", size = 30),
        axis.title.y = element_text(colour = "black", size = 30, vjust = 1),
        axis.text.y = element_text(colour = "black", size = 30),
        axis.ticks = element_line(colour = "black", size = 1),
        plot.margin = unit(c(1, 1, 1, 1),"cm"))

ggsave("pInf.pdf", width = 9, height = 8, unit = "in", dpi = 600)


#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Diplo abundance

SEalltDpl <- summarySE(dplyr::filter(data_dpl, inf.status_cat == "infected"), measurevar = "diplo_total", groupvars = "family.type", na.rm = T)

### Diplo_Total plot
ptDpl <- ggplot(dplyr::filter(data_dpl, inf.status_cat == "infected"),
                aes(x = pop.type, 
                    y = diplo_total, 
                    colour = pop.type, 
                    fill = pop.type, 
                    group = pop.type))

#set our position argument as an object
dodge.posn.basic <-position_dodge(width = 0.4)
dodge.posn       <- position_jitterdodge(jitter.width = 0.8, dodge.width = 0.4)


ptDpl +
  geom_point(shape = 16, 
             size = 5,
             alpha = 0.2,
             position = dodge.posn) +
  stat_summary(fun.data = mean_cl_boot, # 95% CI
               fun.args = (conf.int = 0.95),
               size = 1,
               width = 0.2,
               geom = "errorbar",
               color = "black",
               position = dodge.posn.basic) +
  stat_summary(fun.y = mean,
               geom = "point",
               shape = 19,
               size = 10,
               position = dodge.posn.basic) +
  scale_x_discrete(name = "",
                   limits = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                   breaks = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                   labels = c("SKO-River" = "River", "SKO-Hyb" = "Hybrids", "SKO-Lake" = "Lake", "GPS-Lake" = "GPS")) +
  scale_y_continuous(name = "Metacercariae abundance\n",
                     limit = c(0,50),
                     expand = c(0,0)) +
  scale_colour_manual(name = "",
                      labels = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                      values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff", "GPS-Lake" = "dodgerblue3")) +
  scale_fill_manual(name = "", #name = "Fish population",
                    labels = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                    values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff", "GPS-Lake" = "dodgerblue3")) +
  theme(panel.background = element_blank(),
        title = element_text(colour = "black", size = 18),
        axis.line.x = element_line(colour = "black", size = 1),
        axis.line.y = element_line(colour = "black", size = 1),
        legend.position = "none",
        axis.title.x = element_text(colour = "black", size = 30, vjust = -0.4),
        axis.text.x = element_text(colour = "black", size = 30),
        axis.title.y = element_text(colour = "black", size = 33, vjust = 1),
        axis.text.y = element_text(colour = "black", size = 30),
        axis.ticks = element_line(colour = "black", size = 1),
        plot.margin = unit(c(1, 1, 1, 1),"cm"))

## Export
ggsave("ptDpl.pdf", width = 9, height = 8, unit = "in", dpi = 600)


#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Fish parameters


### Fish condition
dat_cond_red <- na.omit(data_dpl[, c("SL", "somatic.weight.kg", "sex", "family.type", "pop.type", "fish.family.M", "fish.family.F")])  # removing NAs
modx <- lmer(log10(somatic.weight.kg) ~ log10(SL) + sex + (1|fish.family.M) + (1|fish.family.F),
             data = dat_cond_red)
dat_cond_red$mod_resid <- resid(modx)

pRFW <- ggplot(dat_cond_red,
               aes(x = pop.type,
                   y = mod_resid,
                   shape = pop.type,
                   colour = pop.type,
                   fill = pop.type,
                   group = pop.type))
ttl.y <- "Fish condition\n"
lim <- c(-0.13,0.13)


### Residual liver weight
dat_cond_red <- na.omit(data_dpl[, c("liver", "somatic.weight.kg", "sex", "family.type", "pop.type", "fish.family.M", "fish.family.F")])  # removing NAs
modx <- lmer(log10(liver) ~ log10(somatic.weight.kg) + sex + (1|fish.family.M) + (1|fish.family.F),
             data = dat_cond_red)
dat_cond_red$mod_resid <- resid(modx)

pRLW <- ggplot(dat_cond_red,
               aes(x = pop.type,
                   y = mod_resid,
                   shape = pop.type,
                   colour = pop.type,
                   fill = pop.type,
                   group = pop.type))
ttl.y <- "Residual liver weight\n"
lim <- c(-0.35,0.35)


### Residual spleen weight
dat_cond_red <- na.omit(data_dpl[, c("spleen", "somatic.weight.kg", "sex", "family.type", "pop.type", "fish.family.M", "fish.family.F")])  # removing NAs
modx <- lmer(log10(spleen) ~ log10(somatic.weight.kg) + sex + (1|fish.family.M) + (1|fish.family.F),
             data = dat_cond_red)
dat_cond_red$mod_resid <- resid(modx)

pRSW <- ggplot(dat_cond_red,
               aes(x = pop.type,
                   y = mod_resid,
                   shape = pop.type,
                   colour = pop.type,
                   fill = pop.type,
                   group = pop.type))
ttl.y <- "Residual spleen weight\n"
lim <- c(-1,1)


### Residual HK weight
dat_cond_red <- na.omit(data_dpl[, c("HK", "somatic.weight.kg", "sex", "family.type", "pop.type", "fish.family.M", "fish.family.F")])  # removing NAs
modx <- lmer(log10(HK) ~ log10(somatic.weight.kg) + sex + (1|fish.family.M) + (1|fish.family.F),
             data = dat_cond_red)
dat_cond_red$mod_resid <- resid(modx)

pRHKW <- ggplot(dat_cond_red,
                aes(x = pop.type,
                    y = mod_resid,
                    shape = pop.type,
                    colour = pop.type,
                    fill = pop.type,
                    group = pop.type))
ttl.y <- "Residual head kidney weight\n"
lim <- c(-1.2,1.2)


#set our position argument as an object
dodge.posn.basic <- position_dodge(width = 0.4)
dodge.posn       <- position_jitterdodge(jitter.width = 0.8, dodge.width = 0.4)


pRFW +
  #pRLW +
  #pRSW +
  #pRHKW +
  geom_point(shape = 16, 
             size = 5,
             alpha = 0.1,
             position = dodge.posn) +
  stat_summary(fun.data = mean_cl_boot, # 95% CI
               fun.args = (conf.int = 0.95),
               size = 1,
               width = 0.2,
               geom = "errorbar",
               color = "black",
               position = dodge.posn.basic) +
  stat_summary(fun.y = mean,
               geom = "point",
               shape = 19,
               size = 10,
               position = dodge.posn.basic) +
  scale_x_discrete(name = "",
                   limits = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                   breaks = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                   labels = c("SKO-River" = "River", "SKO-Hyb" = "Hybrids", "SKO-Lake" = "Lake", "GPS-Lake" = "GPS")) +
  scale_y_continuous(ttl.y,
                     limits = lim,
                     breaks = pretty_breaks(n = 4),
                     expand = c(0,0)) +
  scale_colour_manual(name = "",
                      labels = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                      values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff", "GPS-Lake" = "dodgerblue3")) +
  scale_fill_manual(name = "", #name = "Fish population",
                    labels = c("SKO-River", "SKO-Hyb", "SKO-Lake", "GPS-Lake"),
                    values = c("SKO-River" = "#ff8d1e", "SKO-Hyb"  = "#80999A", "SKO-Lake"  = "#1e90ff", "GPS-Lake" = "dodgerblue3")) +
  theme(panel.background = element_blank(),
        title = element_text(colour = "black", size = 18),
        axis.line.x = element_line(colour = "black", size = 1),
        axis.line.y = element_line(colour = "black", size = 1),
        legend.position = "none",
        axis.title.x = element_text(colour = "black", size = 30, vjust = -0.4),
        axis.text.x = element_text(colour = "black", size = 30),
        axis.title.y = element_text(colour = "black", size = 33, vjust = 1),
        axis.text.y = element_text(colour = "black", size = 33),
        axis.ticks = element_line(colour = "black", size = 1),
        plot.margin = unit(c(1, 1, 1, 1),"cm"))

## Export
ggsave("CFplot.pdf", width = 9, height = 8, unit = "in", dpi = 600)


