# Erin_etal_2019_Diplo_Stats
# Date: April 2019
# Code description: code to replicate statistical analysis of experimental infection with D. pseudospathaceum from Erin et al. 2019 (J. Anim. Ecol)
# Code authors: Code developed by Noemie I. Erin, and Daniel P. Benesh

# Clear workspace
rm(list =ls())
dev.off()

# libraries
library(dplyr)    #filter, mutate
library(lme4)     #glmer, lmer
library(car)      #Anova
library(lsmeans)  #lsmeans
library(multcomp) #glht












######################################################################################################################
################################################      Data input      ################################################
######################################################################################################################

setwd("C:/")

# import dataset:
input_file_dpl <- "/Erin_etal_2019_Diplo.txt"

data_dpl <- read.delim(input_file_dpl)











#>>>>> To load data, run script until 'Statistical analysis' >>>>>

######################################################################################################################
###################################      Data subsets & Parameter calculations      ##################################
######################################################################################################################

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Data rescaling

# reunited fish family
levels(data_dpl$fish.family)[levels(data_dpl$fish.family)=="SKO-Hyb-L003MxR003F/2"] <- "SKO-Hyb-L003MxR003F"

# put weight into kg - allows model fitting
data_dpl <- mutate(data_dpl, somatic.weight.kg = somatic.weight/1000)











#>>>>> Statistical analysis (excluding GPS fish) >>>>>

######################################################################################################################
###########################################      Statistical analysis      ###########################################
######################################################################################################################

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  D. pseudospathaceum abundance

hist(data_dpl$diplo_total)

# (i) add first variable of family.type
mod0 <- glmer(diplo_total ~ somatic.weight.kg + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
              data = dplyr::filter(data_dpl, pop.type != "GPS-Lake", inf.status_cat == "infected"),
              family = "poisson")
summary(mod0)
Anova(mod0, type = "III")
lsmeans(mod0, pairwise ~ family.type, adjust = "tukey")   # Post-hoc test
b = summary(glht(mod0, linfct = mcp("family.type" = "Tukey")))
cld(b, level = 0.05, decreasing = FALSE)

# (ii) add first variable of pop.type
mod1 <- glmer(diplo_total ~ somatic.weight.kg + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
                data = dplyr::filter(data_dpl, pop.type != "GPS-Lake", inf.status_cat == "infected"),
                family = "poisson")
summary(mod1)
Anova(mod1, type = "III")
lsmeans(mod1, pairwise ~ pop.type, adjust = "tukey")      # Post-hoc test
b = summary(glht(mod1, linfct = mcp("pop.type" = "Tukey")))
cld(b, level = 0.05, decreasing = FALSE)



#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Fish condition

# (i) add first variable of family.type
mod0 <- lmer(log10(somatic.weight.kg) ~ log10(SL) + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
             data = dplyr::filter(data_dpl, pop.type != "GPS-Lake"))
summary(mod0)
Anova(mod0, type = "III")

# (ii) add first variable of pop.type
mod1 <- lmer(log10(somatic.weight.kg) ~ log10(SL) + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
               data = dplyr::filter(data_dpl, pop.type != "GPS-Lake"))
summary(mod1)
Anova(mod1, type = "III")



#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Relative liver weight

# (i) add first variable of family.type
mod0 <- lmer(log10(liver) ~ log10(somatic.weight.kg) + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
             data = dplyr::filter(data_dpl, pop.type != "GPS-Lake"))
summary(mod0)
Anova(mod0, type = "III")
lsmeans(mod0, pairwise ~ family.type, adjust = "tukey")   # Post-hoc test

# (ii) add first variable of pop.type
mod1 <- lmer(log10(liver) ~ log10(somatic.weight.kg) + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
               data = dplyr::filter(data_dpl, pop.type != "GPS-Lake"))
summary(mod1)
Anova(mod1, type = "III")
lsmeans(mod1, pairwise ~ pop.type, adjust = "tukey")      # Post-hoc test
b = summary(glht(mod1, linfct = mcp("pop.type" = "Tukey")))
cld(b, level = 0.05, decreasing = FALSE)



#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Relative spleen weight

# (i) add first variable of family.type
mod0 <- lmer(log10(spleen) ~ log10(somatic.weight.kg) + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
             data = dplyr::filter(data_dpl, pop.type != "GPS-Lake"))
summary(mod0)
Anova(mod0, type = "III")
lsmeans(mod0, pairwise ~ family.type, adjust = "tukey")   # Post-hoc test

# (ii) add first variable of pop.type
mod1 <- lmer(log10(spleen) ~ log10(somatic.weight.kg) + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
               data = dplyr::filter(data_dpl, pop.type != "GPS-Lake"))
summary(mod1)
Anova(mod1, type = "III")
lsmeans(mod1, pairwise ~ pop.type, adjust = "tukey")      # Post-hoc test
b = summary(glht(mod1, linfct = mcp("pop.type" = "Tukey")))
cld(b, level = 0.05, decreasing = FALSE)



#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Relative head kidney weight

# (i) add first variable of family.type
mod0 <- lmer(log10(HK) ~ log10(somatic.weight.kg) + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
             data = dplyr::filter(data_dpl, pop.type != "GPS-Lake"))
summary(mod0)
Anova(mod0, type = "III")

# (ii) add first variable of pop.type
mod1 <- lmer(log10(HK) ~ log10(somatic.weight.kg) + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
               data = dplyr::filter(data_dpl, pop.type != "GPS-Lake"))
summary(mod1)
Anova(mod1, type = "III")











#>>>>> Statistical analysis (including GPS fish) >>>>>

######################################################################################################################
###########################################      Statistical analysis      ###########################################
######################################################################################################################

#---------------------------------------------------------------------------------------------------------------------
#--------------------------  D. pseudospathaceum abundance

hist(data_dpl$diplo_total)

# (i) add first variable of family.type
mod0 <- glmer(diplo_total ~ somatic.weight.kg + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
              data = dplyr::filter(data_dpl, inf.status_cat == "infected", sex != "NA"),
              family = "poisson")
summary(mod0)
Anova(mod0, type = "III")
lsmeans(mod0, pairwise ~ family.type, adjust = "tukey")   # Post-hoc test

# (ii) add first variable of pop.type
mod1 <- glmer(diplo_total ~ somatic.weight.kg + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
              na.action = na.exclude,
              data = dplyr::filter(data_dpl, inf.status_cat == "infected", sex != "NA"),
              family = "poisson")
summary(mod1)
Anova(mod1, type = "III")
lsmeans(mod1, pairwise ~ pop.type, adjust = "tukey")     # Post-hoc test
b = summary(glht(mod1, linfct = mcp("pop.type" = "Tukey")))
cld(b, level = 0.05, decreasing = FALSE)   



#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Fish condition

# (i) add first variable of family.type
mod0 <- lmer(log10(somatic.weight.kg) ~ log10(SL) + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
             data = data_dpl)
summary(mod0)
Anova(mod0, type = "III")
lsmeans(mod0, pairwise ~ family.type, adjust = "tukey")   # Post-hoc test

# (ii) add first variable of pop.type
mod1 <- lmer(log10(somatic.weight.kg) ~ log10(SL) + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
               data = data_dpl)
summary(mod1)
Anova(mod1, type = "III")
lsmeans(mod1, pairwise ~ pop.type, adjust = "tukey")      # Post-hoc test
b = summary(glht(mod1, linfct = mcp("pop.type" = "Tukey")))
cld(b, level = 0.05, decreasing = FALSE)



#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Relative liver weight

# (i) add first variable of family.type
mod0 <- lmer(log10(liver) ~ log10(somatic.weight.kg) + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
             data = data_dpl)
summary(mod0)
Anova(mod0, type = "III")
lsmeans(mod0, pairwise ~ family.type, adjust = "tukey")   # Post-hoc test

# (ii) add first variable of pop.type
mod1 <- lmer(log10(liver) ~ log10(somatic.weight.kg) + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
               data = data_dpl)
summary(mod1)
Anova(mod1, type = "III")
lsmeans(mod1, pairwise ~ pop.type, adjust = "tukey")      # Post-hoc test
b = summary(glht(mod1, linfct = mcp("pop.type" = "Tukey")))
cld(b, level = 0.05, decreasing = FALSE)



#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Relative spleen weight

# (i) add first variable of family.type
mod0 <- lmer(log10(spleen) ~ log10(somatic.weight.kg) + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
             data = data_dpl)
summary(mod0)
Anova(mod0, type = "III")
lsmeans(mod0, pairwise ~ family.type, adjust = "tukey")   # Post-hoc test

# (ii) add first variable of pop.type
mod1 <- lmer(log10(spleen) ~ log10(somatic.weight.kg) + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
               data = data_dpl)
summary(mod1)
Anova(mod1, type = "III")
lsmeans(mod1, pairwise ~ pop.type, adjust = "tukey")      # Post-hoc test
b = summary(glht(mod1, linfct = mcp("pop.type" = "Tukey")))
cld(b, level = 0.05, decreasing = FALSE)



#---------------------------------------------------------------------------------------------------------------------
#--------------------------  Relative head kidney weight

# (i) add first variable of family.type
mod0 <- lmer(log10(HK) ~ log10(somatic.weight.kg) + sex + family.type + (1|fish.family.M) + (1|fish.family.F),
             data = data_dpl)
summary(mod0)
Anova(mod0, type = "III")

# (ii) add first variable of pop.type
mod1 <- lmer(log10(HK) ~ log10(somatic.weight.kg) + sex + pop.type + (1|fish.family.M) + (1|fish.family.F),
               data = data_dpl)
summary(mod1)
Anova(mod1, type = "III")


